@@ -1,6 +1,6 @@
 #' Label categorical variables from PNAD COVID19 microdata
 #' @description This function labels categorical variables from PNAD COVID19 microdata.
-#' @import survey readr dplyr magrittr RCurl utils timeDate readxl tibble
+#' @import survey readr dplyr magrittr projmgr httr RCurl utils timeDate readxl tibble
 #' @param data_covid A tibble of PNAD COVID19 microdata read with \code{read_covid} function.
 #' @param dictionary.file The dictionary file for selected survey available on official website: (select a dictionary xls file) - \url{https://ftp.ibge.gov.br/Trabalho_e_Rendimento/Pesquisa_Nacional_por_Amostra_de_Domicilios_PNAD_COVID19/Microdados/Documentacao/}.
 #' @return A tibble with the data provided from PNAD COVID19 survey and its categorical variables as factors with related labels.
@@ -71,7 +71,7 @@ covid_labeller <- function(data_covid, dictionary.file) {
     }
   }
   else {
-    warning("Sample design was already defined for microdata, so labelling categorical variables is not possible.")
+    message("The microdata object is not of the tibble class or sample design was already defined for microdata, so labelling categorical variables is not possible.")
   }
   return(data_covid)
 }
