@@ -1,8 +1,8 @@
 #' Download, label, deflate and create survey design object for PNAD COVID19 microdata
 #' @description Core function of package. With this function only, the user can download a PNAD COVID19 microdata from a month and get a sample design object ready to use with \code{survey} package functions.
-#' @import survey readr dplyr magrittr RCurl utils timeDate readxl tibble
-#' @param year The year of the data to be downloaded. Must be a number between 2020 and current year. Vector not accepted.
-#' @param month The month of the year of the data to be downloaded. Must be number from 1 to 12. If the year is defined as 2020, must be a number from 5 to 12. Vector not accepted.
+#' @import survey readr dplyr magrittr projmgr httr RCurl utils timeDate readxl tibble
+#' @param year The year of the data to be downloaded. Must be a number equal to 2020. Vector not accepted.
+#' @param month The month of the year of the data to be downloaded. Must be number from 5 to 11. Vector not accepted.
 #' @param vars Vector of variable names to be kept for analysis. Default is to keep all variables.
 #' @param labels Logical value. If \code{TRUE}, categorical variables will presented as factors with labels corresponding to the survey's dictionary.
 #' @param deflator Logical value. If \code{TRUE}, deflator variables will be available for use in the microdata.
@@ -15,32 +15,36 @@
 #' \donttest{
 #' covid.svy <- get_covid(year=2020, month=5, vars=c("C001","C002","C003"),
 #'                        labels=TRUE, deflator=TRUE, design=TRUE, savedir=tempdir())
-#' survey::svymean(x=~C002, design=covid.svy, na.rm=TRUE)}
+#' if (!is.null(covid.svy)) survey::svymean(x=~C002, design=covid.svy, na.rm=TRUE)}
 #' @export
 
 get_covid <- function(year, month, vars = NULL,
                        labels = TRUE, deflator = TRUE, design = TRUE, savedir = tempdir())
 {
-  if (year < 2020) {
-    stop("Year must be greater or equal to 2012.")
+  if (year != 2020) {
+    message("Year must be equal to 2020.")
+    return(NULL)
   }
-  if (year > timeDate::getRmetricsOptions("currentYear")) {
-    stop("Year cannot be greater than current year.")
-  }
-  if (month < 1 | month > 12) {
-    stop("Month number must be an integer from 1 to 12.")
-  }
-  if (year == 2020 & month < 5) {
-    stop("If the year is defined as 2020, month must be an integer from 5 to 12.")
+  if (month < 5 | month > 11) {
+    message("Month number must be an integer from 5 to 11.")
+    return(NULL)
   }
   if (!dir.exists(savedir)) {
     savedir <- tempdir()
-    warning(paste0("The directory provided does not exist, so the directory was set to '", tempdir()), "'.")
+    message(paste0("The directory provided does not exist, so the directory was set to '", tempdir()), "'.")
   }
   if (substr(savedir, nchar(savedir), nchar(savedir)) == "/" | substr(savedir, nchar(savedir), nchar(savedir)) == "\\") {
     savedir <- substr(savedir, 1, nchar(savedir)-1)
   }
   ftpdir <- ("ftp://ftp.ibge.gov.br/Trabalho_e_Rendimento/Pesquisa_Nacional_por_Amostra_de_Domicilios_PNAD_COVID19/Microdados/")
+  if (!projmgr::check_internet()) {
+    message("The internet connection is unavailable.")
+    return(NULL)
+  }
+  if (httr::http_error(GET(ftpdir, timeout(60)))) {
+    message("The microdata server is unavailable.")
+    return(NULL)
+  }
   ftpdata <- paste0(ftpdir, "Dados/")
   ftpdoc <- paste0(ftpdir, "Documentacao/")
   datayear <- unlist(strsplit(gsub("\r\n", "\n", RCurl::getURL(ftpdata, dirlistonly=TRUE)), "\n"))
@@ -51,7 +55,8 @@ get_covid <- function(year, month, vars = NULL,
     dataname <- datayear[which(startsWith(datayear, paste0("PNAD_COVID_", month, year)))]
   }
   if (length(dataname) == 0) {
-    stop("Data unavailable for selected year.")
+    message("Data unavailable for selected year.")
+    return(NULL)
   }
   utils::download.file(url=paste0(ftpdata, dataname), destfile=paste0(savedir, "/", dataname), mode="wb")
   utils::unzip(zipfile=paste0(savedir, "/", dataname), exdir=savedir)
@@ -79,7 +84,7 @@ get_covid <- function(year, month, vars = NULL,
       data_covid <- COVIDIBGE::covid_labeller(data_covid=data_covid, dictionary.file=dicfile)
     }
     else {
-      warning("Labeller function is unavailable in package COVIDIBGE.")
+      message("Labeller function is unavailable in package COVIDIBGE.")
     }
   }
   if (deflator == TRUE) {
@@ -93,7 +98,7 @@ get_covid <- function(year, month, vars = NULL,
       data_covid <- COVIDIBGE::covid_deflator(data_covid=data_covid, deflator.file=deffile)
     }
     else {
-      warning("Deflator function is unavailable in package COVIDIBGE.")
+      message("Deflator function is unavailable in package COVIDIBGE.")
     }
   }
   if (design == TRUE) {
@@ -101,7 +106,7 @@ get_covid <- function(year, month, vars = NULL,
       data_covid <- COVIDIBGE::covid_design(data_covid=data_covid)
     }
     else {
-      warning("Sample design function is unavailable in package COVIDIBGE.")
+      message("Sample design function is unavailable in package COVIDIBGE.")
     }
   }
   return(data_covid)
